@@ -392,13 +392,14 @@ class TestLoggingInteraction:
 
 
 class TestCaptureFixture:
-    def test_std_functional(self, testdir):
+    @pytest.mark.parametrize("opt", [[], ["-s"]])
+    def test_std_functional(self, testdir, opt):
         reprec = testdir.inline_runsource("""
             def test_hello(capsys):
                 print (42)
                 out, err = capsys.readouterr()
                 assert out.startswith("42")
-        """)
+        """, *opt)
         reprec.assertoutcome(passed=1)
 
     def test_capsyscapfd(self, testdir):
@@ -1011,3 +1012,13 @@ def test_capturing_and_logging_fundamentals(testdir, method):
     """)
     assert "atexit" not in result.stderr.str()
 
+
+def test_error_attribute_issue555(testdir):
+    testdir.makepyfile("""
+        import sys
+        def test_capattr():
+            assert sys.stdout.errors == "strict"
+            assert sys.stderr.errors == "strict"
+    """)
+    reprec = testdir.inline_run()
+    reprec.assertoutcome(passed=1)
